package cn.iocoder.yudao.module.jx.service;

import cn.iocoder.yudao.module.jx.domain.DriveSchoolNotice;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import javax.imageio.IIOParam;
import java.util.List;

/**
 * 通知Service接口
 *
 * @author ruoyi
 * @date 2024-05-28
 */
public interface IDriveSchoolNoticeService
{
    /**
     * 查询通知
     *
     * @param id 通知主键
     * @return 通知
     */
    public DriveSchoolNotice selectDriveSchoolNoticeById(Long id);

    /**
     * 查询通知列表
     *
     * @param driveSchoolNotice 通知
     * @return 通知集合
     */
    public IPage<DriveSchoolNotice> selectDriveSchoolNoticeList(DriveSchoolNotice driveSchoolNotice, Page<DriveSchoolNotice> page);
    public List<DriveSchoolNotice> selectDriveSchoolNoticeAppList(DriveSchoolNotice driveSchoolNotice);

    /**
     * 新增通知
     *
     * @param driveSchoolNotice 通知
     * @return 结果
     */
    public int insertDriveSchoolNotice(DriveSchoolNotice driveSchoolNotice);

    /**
     * 修改通知
     *
     * @param driveSchoolNotice 通知
     * @return 结果
     */
    public int updateDriveSchoolNotice(DriveSchoolNotice driveSchoolNotice);

    /**
     * 批量删除通知
     *
     * @param ids 需要删除的通知主键集合
     * @return 结果
     */
    public int deleteDriveSchoolNoticeByIds(Long[] ids);

    /**
     * 删除通知信息
     *
     * @param id 通知主键
     * @return 结果
     */
    public int deleteDriveSchoolNoticeById(Long id);
}
